@@ -55,12 +55,13 @@
 
 ;; ------------------------------------------------------------------------ ;;
 
-(defconst javascript-mode-version "1.6" "Version of `javascript-mode'.")
+(defconst javascript-mode-version "1.7" "Version of `javascript-mode'.")
 
 ;; ------------------------------------------------------------------------ ;;
 
 (defgroup javascript nil
   "Major mode for editing JavaScript code."
+  :tag "JavaScript"
   :group 'languages
   :prefix "javascript-")
 
@@ -247,37 +248,41 @@ From Core JavaScript Guide 1.5, Chapter 2 (Values, Variables and Literals):
 See the documentation for `c++-mode': JavaScript mode is an extension of it.
 Use the hook `javascript-mode-hook' to execute custom code when entering
 JavaScript mode.
+
 \\{javascript-mode-map}"
   (interactive)
 
   (let ((current-c++-mode-hook (and (boundp 'c++-mode-hook) c++-mode-hook)))
 
-    ; Temporarily disable the c++-mode hook; don't wanna run
-    ; it when loading up c++-mode.
+    ;; Temporarily disable the c++-mode hook; don't wanna run
+    ;; it when loading up c++-mode.
     (setq c++-mode-hook nil)
     (c++-mode)
 
-    ; Do our stuff.
+    ;; Do our stuff.
     (setq major-mode 'javascript-mode mode-name "JavaScript")
     (use-local-map javascript-mode-map)
     (setq local-abbrev-table javascript-mode-abbrev-table)
     (c-set-offset 'inher-cont '+)
 
-    ; GNU Emacs reportedly needs this for font locking to work properly.
+    ;; Change menu name.  Kudos to Geert Ribbers.
+    (easy-menu-remove '("C++"))
+    (easy-menu-add (c-mode-menu "JavaScript") javascript-mode-map)
+
+    ;; GNU Emacs reportedly needs this for font locking to work properly.
     (unless (featurep 'xemacs)
       (set (make-local-variable 'font-lock-defaults)
            '(javascript-font-lock-keywords nil nil)))
 
-    ; cc-mode does not handle JavaScript prototype function declarations well.
-    ; Thanks to Sebastian Delmont.
+    ;; cc-mode does not handle JavaScript prototype function declarations well.
+    ;; Thanks to Sebastian Delmont.
     (set (make-local-variable 'c-lambda-key) "function")
     (c-set-offset 'inlambda 0)
 
-    ; Restore the original c++-mode-hook.
+    ;; Restore the original c++-mode-hook.
     (setq c++-mode-hook current-c++-mode-hook)
 
-    (run-hooks 'javascript-mode-hook)
-    ))
+    (run-hooks 'javascript-mode-hook)))
 
 ;; ------------------------------------------------------------------------ ;;
 
