@@ -5,10 +5,10 @@
 ;; Maintainer: Turadg Aleahmad <turadg at users.sourceforge.net>
 ;; Keywords: php languages oop
 ;; Created: 1999-05-17
-;; Modified: 2001-11-03
-;; X-URL:   http://php-mode.sourceforge.net/
+;; Modified: 2002-01-22
+;; X-URL:   http://php-mode.sf.net/
 
-(defconst php-version "1.0.1"
+(defconst php-version "1.0.2"
   "PHP Mode version number.")
 
 ;;; License
@@ -31,7 +31,13 @@
 
 ;; Place this file in your Emacs lisp path (eg. site-lisp)
 ;; and add to your .emacs file:
-;; (load-library "php-mode-101")
+;;   (load-library "php-mode-102")
+
+;; If you want colorization, turn on global-font-lock or
+;; add this to your .emacs:
+;;   (add-hook 'php-mode-user-hook 'turn-on-font-lock)
+
+;; To make php-mode compatible with html-mode, see php-mode.sf.net
 
 ;; Many options available under Help:Customize
 ;; Options specific to php-mode are in
@@ -51,6 +57,13 @@
 
 ;;; Changelog:
 
+;; 1.02
+;;   Highlight HTML tags and entities (see site for more on HTML)
+;;   Highlight more constants by default
+;;   Fixed problem with $-line indenting inside switch (see comments)
+;;   Fix to show keymap in help mode (Ryan Sammartino)
+;;   Added .phps to default extensions to match (John Keller)
+
 ;; 1.0.1
 ;;   Fix for some speedbar problems
 
@@ -164,7 +177,7 @@
 
 (defcustom php-speedbar-config t
   "*When set to true automatically configures Speedbar to observe PHP files.\
-Ignores php-file patterns option; fixed to expression \"\\.\\(inc\\|php[34]?\\)\""
+Ignores php-file patterns option; fixed to expression \"\\.\\(inc\\|php[s34]?\\)\""
   :type 'boolean
   :group 'php)
 
@@ -186,7 +199,7 @@ You can replace \"en\" with your ISO language code."
   :group 'php)
 
 ;;;###autoload
-(defcustom php-file-patterns (list "\\.php[34]?\\'" "\\.phtml\\'" "\\.inc\\'")
+(defcustom php-file-patterns (list "\\.php[s34]?\\'" "\\.phtml\\'" "\\.inc\\'")
   "*List of file patterns for which to automatically invoke php-mode."
   :type '(repeat (regexp :tag "Pattern"))
   :group 'php)
@@ -206,9 +219,11 @@ Turning this on will force PEAR rules on all PHP files."
 (defconst xemacsp (string-match "Lucid\\|XEmacs" emacs-version)
   "Non nil if using XEmacs.")
 
+;; XEmacs hack: autoload a dummy autoload instead of a derived mode.
 ;;;###autoload
+(autoload 'php-mode "php-mode")
 (define-derived-mode php-mode c-mode "PHP"
-  "Major mode for editing PHP code.\n\n{php-mode-map}"
+  "Major mode for editing PHP code.\n\n\\{php-mode-map}"
   
   (setq comment-start "// "
 	comment-end   ""
@@ -218,9 +233,13 @@ Turning this on will force PEAR rules on all PHP files."
   ;; underscore considered part of word
   (modify-syntax-entry ?_ "w" php-mode-syntax-table)
   ;; dollar-sign considered punctuation, not part of word
-  (modify-syntax-entry ?$ "." php-mode-syntax-table)
+  ;; 2002-01-22: I don't remember saying the above so I'm commenting
+  ;; this out because it kills indenting of case lines that begin with $
+  ;; Let me know if you have a case for keeping it in, preferably
+  ;; along with a solution to the switch indenting problem
+;  (modify-syntax-entry ?$ "." php-mode-syntax-table)
   
-  ;; The above causes Xemacs to handle shell-style comments correctly,
+  ;; The above causes XEmacs to handle shell-style comments correctly,
   ;; but fails to work in GNU Emacs which fails to interpret \n as the
   ;; end of the comment.
   (if xemacsp (progn
@@ -289,7 +308,7 @@ Turning this on will force PEAR rules on all PHP files."
 (if php-mode-speedbar-open
     (speedbar 1))
 (if (and php-speedbar-config (symbolp 'speedbar))
-    (speedbar-add-supported-extension "\\.\\(inc\\|php[34]?\\)"))
+    (speedbar-add-supported-extension "\\.\\(inc\\|php[s34]?\\)"))
 
 ;; Make a menu keymap (with a prompt string)
 ;; and make it the menu bar item's definition.
@@ -359,42 +378,42 @@ Turning this on will force PEAR rules on all PHP files."
        "PHP_BINDIR" "PHP_LIBDIR" "PHP_DATADIR" "PHP_SYSCONFDIR"
        "PHP_LOCALSTATEDIR" "PHP_CONFIG_FILE_PATH"
 
+       ;; from ext/standard:
+       "EXTR_OVERWRITE" "EXTR_SKIP" "EXTR_PREFIX_SAME"
+       "EXTR_PREFIX_ALL" "EXTR_PREFIX_INVALID" "SORT_ASC" "SORT_DESC"
+       "SORT_REGULAR" "SORT_NUMERIC" "SORT_STRING" "ASSERT_ACTIVE"
+       "ASSERT_CALLBACK" "ASSERT_BAIL" "ASSERT_WARNING"
+       "ASSERT_QUIET_EVAL" "CONNECTION_ABORTED" "CONNECTION_NORMAL"
+       "CONNECTION_TIMEOUT" "M_E" "M_LOG2E" "M_LOG10E" "M_LN2"
+       "M_LN10" "M_PI" "M_PI_2" "M_PI_4" "M_1_PI" "M_2_PI"
+       "M_2_SQRTPI" "M_SQRT2" "M_SQRT1_2" "CRYPT_SALT_LENGTH"
+       "CRYPT_STD_DES" "CRYPT_EXT_DES" "CRYPT_MD5" "CRYPT_BLOWFISH"
+       "DIRECTORY_SEPARATOR" "SEEK_SET" "SEEK_CUR" "SEEK_END"
+       "LOCK_SH" "LOCK_EX" "LOCK_UN" "LOCK_NB" "HTML_SPECIALCHARS"
+       "HTML_ENTITIES" "ENT_COMPAT" "ENT_QUOTES" "ENT_NOQUOTES"
+       "INFO_GENERAL" "INFO_CREDITS" "INFO_CONFIGURATION"
+       "INFO_ENVIRONMENT" "INFO_VARIABLES" "INFO_LICENSE" "INFO_ALL"
+       "CREDITS_GROUP" "CREDITS_GENERAL" "CREDITS_SAPI"
+       "CREDITS_MODULES" "CREDITS_DOCS" "CREDITS_FULLPAGE"
+       "CREDITS_QA" "CREDITS_ALL" "PHP_OUTPUT_HANDLER_START"
+       "PHP_OUTPUT_HANDLER_CONT" "PHP_OUTPUT_HANDLER_END"
+       "STR_PAD_LEFT" "STR_PAD_RIGHT" "STR_PAD_BOTH"
+       "PATHINFO_DIRNAME" "PATHINFO_BASENAME" "PATHINFO_EXTENSION"
+       "CHAR_MAX" "LC_CTYPE" "LC_NUMERIC" "LC_TIME" "LC_COLLATE"
+       "LC_MONETARY" "LC_ALL" "LC_MESSAGES" "LOG_EMERG" "LOG_ALERT"
+       "LOG_CRIT" "LOG_ERR" "LOG_WARNING" "LOG_NOTICE" "LOG_INFO"
+       "LOG_DEBUG" "LOG_KERN" "LOG_USER" "LOG_MAIL" "LOG_DAEMON"
+       "LOG_AUTH" "LOG_SYSLOG" "LOG_LPR" "LOG_NEWS" "LOG_UUCP"
+       "LOG_CRON" "LOG_AUTHPRIV" "LOG_LOCAL0" "LOG_LOCAL1"
+       "LOG_LOCAL2" "LOG_LOCAL3" "LOG_LOCAL4" "LOG_LOCAL5"
+       "LOG_LOCAL6" "LOG_LOCAL7" "LOG_PID" "LOG_CONS" "LOG_ODELAY"
+       "LOG_NDELAY" "LOG_NOWAIT" "LOG_PERROR"
+       
        ;; Disabled by default because they slow buffer loading
        ;; If you have use for them, decomment the strings 
        ;; that you want colored.
        ;; To compile, you may have to increase 'max-specpdl-size'
 
-       ;; from ext/standard:
-;        "EXTR_OVERWRITE" "EXTR_SKIP" "EXTR_PREFIX_SAME"
-;        "EXTR_PREFIX_ALL" "EXTR_PREFIX_INVALID" "SORT_ASC" "SORT_DESC"
-;        "SORT_REGULAR" "SORT_NUMERIC" "SORT_STRING" "ASSERT_ACTIVE"
-;        "ASSERT_CALLBACK" "ASSERT_BAIL" "ASSERT_WARNING"
-;        "ASSERT_QUIET_EVAL" "CONNECTION_ABORTED" "CONNECTION_NORMAL"
-;        "CONNECTION_TIMEOUT" "M_E" "M_LOG2E" "M_LOG10E" "M_LN2"
-;        "M_LN10" "M_PI" "M_PI_2" "M_PI_4" "M_1_PI" "M_2_PI"
-;        "M_2_SQRTPI" "M_SQRT2" "M_SQRT1_2" "CRYPT_SALT_LENGTH"
-;        "CRYPT_STD_DES" "CRYPT_EXT_DES" "CRYPT_MD5" "CRYPT_BLOWFISH"
-;        "DIRECTORY_SEPARATOR" "SEEK_SET" "SEEK_CUR" "SEEK_END"
-;        "LOCK_SH" "LOCK_EX" "LOCK_UN" "LOCK_NB" "HTML_SPECIALCHARS"
-;        "HTML_ENTITIES" "ENT_COMPAT" "ENT_QUOTES" "ENT_NOQUOTES"
-;        "INFO_GENERAL" "INFO_CREDITS" "INFO_CONFIGURATION"
-;        "INFO_ENVIRONMENT" "INFO_VARIABLES" "INFO_LICENSE" "INFO_ALL"
-;        "CREDITS_GROUP" "CREDITS_GENERAL" "CREDITS_SAPI"
-;        "CREDITS_MODULES" "CREDITS_DOCS" "CREDITS_FULLPAGE"
-;        "CREDITS_QA" "CREDITS_ALL" "PHP_OUTPUT_HANDLER_START"
-;        "PHP_OUTPUT_HANDLER_CONT" "PHP_OUTPUT_HANDLER_END"
-;        "STR_PAD_LEFT" "STR_PAD_RIGHT" "STR_PAD_BOTH"
-;        "PATHINFO_DIRNAME" "PATHINFO_BASENAME" "PATHINFO_EXTENSION"
-;        "CHAR_MAX" "LC_CTYPE" "LC_NUMERIC" "LC_TIME" "LC_COLLATE"
-;        "LC_MONETARY" "LC_ALL" "LC_MESSAGES" "LOG_EMERG" "LOG_ALERT"
-;        "LOG_CRIT" "LOG_ERR" "LOG_WARNING" "LOG_NOTICE" "LOG_INFO"
-;        "LOG_DEBUG" "LOG_KERN" "LOG_USER" "LOG_MAIL" "LOG_DAEMON"
-;        "LOG_AUTH" "LOG_SYSLOG" "LOG_LPR" "LOG_NEWS" "LOG_UUCP"
-;        "LOG_CRON" "LOG_AUTHPRIV" "LOG_LOCAL0" "LOG_LOCAL1"
-;        "LOG_LOCAL2" "LOG_LOCAL3" "LOG_LOCAL4" "LOG_LOCAL5"
-;        "LOG_LOCAL6" "LOG_LOCAL7" "LOG_PID" "LOG_CONS" "LOG_ODELAY"
-;        "LOG_NDELAY" "LOG_NOWAIT" "LOG_PERROR"
-       
        ;; from other bundled extensions:
 ;        "CAL_EASTER_TO_xxx" "VT_NULL" "VT_EMPTY" "VT_UI1" "VT_I2"
 ;        "VT_I4" "VT_R4" "VT_R8" "VT_BOOL" "VT_ERROR" "VT_CY" "VT_DATE"
@@ -756,6 +775,7 @@ Turning this on will force PEAR rules on all PHP files."
    ;; Fontify ASP-style tag
    '("<\\%\\(=\\)?" . font-lock-constant-face)
    '("\\%>" . font-lock-constant-face)
+
    )
   "Subdued level highlighting for PHP mode.")
 
@@ -787,7 +807,10 @@ Turning this on will force PEAR rules on all PHP files."
     
     ;; <word> or </word> for HTML
     '("</?\\sw+[^>]*>" . font-lock-constant-face)
-    
+
+    ;; HTML entities
+    '("&\\w+;" . font-lock-variable-name-face)
+
     ;; warn about '$' immediately after ->
     '("\\$\\sw+->\\s-*\\(\\$\\)\\(\\sw+\\)"
       (1 font-lock-warning-face) (2 default))
@@ -823,7 +846,7 @@ Turning this on will force PEAR rules on all PHP files."
     ;; Mark shell-style comments.  font-lock handles this in a
     ;; separate pass from normal syntactic scanning (somehow), so we
     ;; get a chance to mark these in addition to C and C++ style
-    ;; comments.  This only works in GNU Emacs, not Xemacs 21 which
+    ;; comments.  This only works in GNU Emacs, not XEmacs 21 which
     ;; seems to ignore this same code if we try to use it.
     (list
      ;; Mark _all_ # chars as being comment-start.  That will be
@@ -858,7 +881,7 @@ Turning this on will force PEAR rules on all PHP files."
     ))
   )
 
-;; Create "default" symbol for GNU Emacs so that both Xemacs and GNU
+;; Create "default" symbol for GNU Emacs so that both XEmacs and GNU
 ;; emacs can refer to the default face by a variable named "default".
 (unless (boundp 'default)
   (defvar default 'default))
